%define upstream_name    JavaScript-Minifier
%define upstream_version 1.16

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Perl extension for minifying JavaScript code
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/JavaScript/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(IO::Handle)
BuildRequires: perl(IPC::Open3)
BuildRequires: perl(Test::More)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%description
This module removes unnecessary whitespace from JavaScript code. The
primary requirement developing this module is to not break working code: if
working JavaScript is in input then working JavaScript is output. It is ok
if the input has missing semi-colons, snips like '++ +' or '12
.toString()', for example. Internet Explorer conditional comments are
copied to the output but the code inside these comments will not be
minified.

The ECMAScript specifications allow for many different whitespace
characters: space, horizontal tab, vertical tab, new line, carriage return,
form feed, and paragraph separator. This module understands all of these as
whitespace except for vertical tab and paragraph separator. These two types
of whitespace are not minimized.

For static JavaScript files, it is recommended that you minify during the
build stage of web deployment. If you minify on-the-fly then it might be a
good idea to cache the minified file. Minifying static files on-the-fly
repeatedly is wasteful.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes INSTALL LICENSE META.yml MYMETA.yml README examples
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Mon Mar 21 2022 umeabot <umeabot> 1.160.0-2.mga9
+ Revision: 1814188
- Mageia 9 Mass Rebuild

* Fri Mar 05 2021 tv <tv> 1.160.0-1.mga9
+ Revision: 1699832
- update to 1.16

* Thu Feb 25 2021 tv <tv> 1.150.0-1.mga9
+ Revision: 1691351
- update to 1.15

* Wed Feb 12 2020 umeabot <umeabot> 1.140.0-5.mga8
+ Revision: 1495223
- Mageia 8 Mass Rebuild

* Wed Sep 19 2018 umeabot <umeabot> 1.140.0-4.mga7
+ Revision: 1268853
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 1.140.0-3.mga6
+ Revision: 1028818
- Rebuild for perl 5.22.2

* Fri Feb 19 2016 umeabot <umeabot> 1.140.0-2.mga6
+ Revision: 968339
- Mageia 6 Mass Rebuild

* Mon Jul 06 2015 sander85 <sander85> 1.140.0-1.mga6
+ Revision: 852029
- update to 1.14

* Sun Oct 19 2014 umeabot <umeabot> 1.110.0-4.mga5
+ Revision: 789421
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 1.110.0-3.mga5
+ Revision: 743948
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.110.0-2.mga5
+ Revision: 685149
- Mageia 5 Mass Rebuild

* Tue Feb 04 2014 guillomovitch <guillomovitch> 1.110.0-1.mga5
+ Revision: 582130
- new version 1.11

* Fri Oct 18 2013 umeabot <umeabot> 1.50.0-3.mga4
+ Revision: 512399
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.50.0-2.mga3
+ Revision: 368825
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Mar 12 2012 guillomovitch <guillomovitch> 1.50.0-1.mga2
+ Revision: 222932
- imported package perl-JavaScript-Minifier


* Mon Mar 12 2012 cpan2dist 1.05-1mga
- initial mageia release, generated with cpan2dist
